<?php
/*-----------------------------------------------------------------------------------*/
/*	Do not remove these lines, sky will fall on your head.
/*-----------------------------------------------------------------------------------*/
define( 'MTS_THEME_NAME', 'cleanapp' );
define( 'MTS_THEME_VERSION', '1.1.9' );

require_once( get_theme_file_path( 'theme-options.php' ) );
if ( ! isset( $content_width ) ) $content_width = 1060;

/*-----------------------------------------------------------------------------------*/
/*	Load Options
/*-----------------------------------------------------------------------------------*/
$mts_options = get_option( MTS_THEME_NAME );
add_theme_support( 'title-tag' );

/*-----------------------------------------------------------------------------------*/
/*	Load Translation Text Domain
/*-----------------------------------------------------------------------------------*/
load_theme_textdomain( 'mythemeshop', get_template_directory().'/lang' );

// Custom translations
if ( !empty( $mts_options['translate'] )) {
    $mts_translations = get_option( 'mts_translations_'.MTS_THEME_NAME );//$mts_options['translations'];
    function mts_custom_translate( $translated_text, $text, $domain ) {
        if ( $domain == 'mythemeshop' || $domain == 'nhp-opts' ) {
            global $mts_translations;
            if ( !empty( $mts_translations[$text] )) {
                $translated_text = $mts_translations[$text];
            }
        }
    	return $translated_text;

    }
    add_filter( 'gettext', 'mts_custom_translate', 20, 3 );
}

if ( function_exists( 'add_theme_support' ) ) add_theme_support( 'automatic-feed-links' );

/*-----------------------------------------------------------------------------------*/
/*  Create Blog page on Theme Activation
/*-----------------------------------------------------------------------------------*/
if (isset($_GET['activated']) && is_admin()){
        $new_page_title = 'Blog';
        $new_page_content = '';
        $new_page_template = 'page-blog.php';
        //don't change the code bellow, unless you know what you're doing
        $page_check = get_page_by_title($new_page_title);
        $new_page = array(
                'post_type' => 'page',
                'post_title' => $new_page_title,
                'post_content' => $new_page_content,
                'post_status' => 'publish',
                'post_author' => 1,
        );
        if(!isset($page_check->ID)){
                $new_page_id = wp_insert_post($new_page);
                if(!empty($new_page_template)){
                        update_post_meta($new_page_id, '_wp_page_template', $new_page_template);
                }
        $page_id = $new_page_id;
        } else {
        $page_id = $page_check->ID;
    }
}

/*-----------------------------------------------------------------------------------*/
/*  Disable theme updates from WordPress.org theme repository
/*-----------------------------------------------------------------------------------*/
// Check if MTS Connect plugin already done this
if ( !class_exists('mts_connection') ) {
    // If wrong updates are already shown, delete transient so that we can run our workaround
    add_action('init', 'mts_hide_themes_plugins');
    function mts_hide_themes_plugins() {
        if ( !is_admin() ) return;
        if ( false === get_site_transient( 'mts_wp_org_check_disabled' ) ) { // run only once
            delete_site_transient('update_themes' );
            delete_site_transient('update_plugins' );

            add_action('current_screen', 'mts_remove_themes_plugins_from_update' );
        }
    }
    // Hide mts themes/plugins
    function mts_remove_themes_plugins_from_update( $screen ) {
        $run_on_screens = array( 'themes', 'themes-network', 'plugins', 'plugins-network', 'update-core', 'network-update-core' );
        if ( in_array( $screen->base, $run_on_screens ) ) {
            //Themes
            if ( $themes_transient = get_site_transient( 'update_themes' ) ) {
                if ( property_exists( $themes_transient, 'response' ) && is_array( $themes_transient->response ) ) {
                    foreach ( $themes_transient->response as $key => $value ) {
                        $theme = wp_get_theme( $value['theme'] );
                        $theme_uri = $theme->get( 'ThemeURI' );
                        if ( 0 !== strpos( $theme_uri, 'mythemeshop.com' ) ) {
                            unset( $themes_transient->response[$key] );
                        }
                    }
                    set_site_transient( 'update_themes', $themes_transient );
                }
            }
            //Plugins
            if ( $plugins_transient = get_site_transient( 'update_plugins' ) ) {
                if ( property_exists( $plugins_transient, 'response' ) && is_array( $plugins_transient->response ) ) {
                    foreach ( $plugins_transient->response as $key => $value ) {
                        $plugin = get_plugin_data( WP_PLUGIN_DIR.'/'.$key, false, false );
                        $plugin_uri = $plugin['PluginURI'];
                        if ( 0 !== strpos( $plugin_uri, 'mythemeshop.com' ) ) {
                            unset( $plugins_transient->response[$key] );
                        }
                    }
                    set_site_transient( 'update_plugins', $plugins_transient );
                }
            }
            set_site_transient( 'mts_wp_org_check_disabled', time() );
        }
    }
    add_action( 'load-themes.php', 'mts_clear_check_transient' );
    add_action( 'load-plugins.php', 'mts_clear_check_transient' );
    add_action( 'upgrader_process_complete', 'mts_clear_check_transient' );
    function mts_clear_check_transient(){
        delete_site_transient( 'mts_wp_org_check_disabled');
    }
}
// Disable auto update
add_filter( 'auto_update_theme', '__return_false' );

/*-----------------------------------------------------------------------------------*/
/*	Post Thumbnail Support
/*-----------------------------------------------------------------------------------*/
if ( function_exists( 'add_theme_support' ) ) {
	add_theme_support( 'post-thumbnails' );
	set_post_thumbnail_size( 223, 137, true );
	add_image_size( 'featured', 555, 300, true ); //featured
	add_image_size( 'widgetthumb', 90, 75, true ); //widget
    add_image_size( 'widgetfull', 300, 200, true ); //sidebar full width
}

function mts_get_thumbnail_url( $size = 'full' ) {
    global $post;
    if (has_post_thumbnail( $post->ID ) ) {
        $image = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), $size );
        return $image[0];
    }

    // use first attached image
    $images =& get_children( 'post_type=attachment&post_mime_type=image&post_parent=' . $post->ID );
    if (!empty($images)) {
        $image = reset($images);
        $image_data = wp_get_attachment_image_src( $image->ID, $size );
        return $image_data[0];
    }

    // use no preview fallback
    if ( file_exists( get_template_directory().'/images/nothumb-'.$size.'.png' ) )
        return get_template_directory_uri().'/images/nothumb-'.$size.'.png';
    else
        return '';
}

/*-----------------------------------------------------------------------------------*/
/*	Custom Menu Support
/*-----------------------------------------------------------------------------------*/
if ($mts_options['mts_show_nav'] == '1') {
add_theme_support( 'menus' );
if ( function_exists( 'register_nav_menus' ) ) {
	register_nav_menus(
		array(
		  'primary-menu' => __( 'Primary Menu', 'mythemeshop' ),
		 )
	 );
}
}

/*-----------------------------------------------------------------------------------*/
/*	Enable Widgetized sidebar and Footer
/*-----------------------------------------------------------------------------------*/
if ( function_exists( 'register_sidebar' ) ) {
    function mts_register_sidebars() {
        $mts_options = get_option( MTS_THEME_NAME );

        // Left sidebar
        register_sidebar( array(
            'name' => 'Left Sidebar',
            'description'   => __( 'Left sidebar.', 'mythemeshop' ),
            'id' => 'left-sidebar',
            'before_widget' => '<div id="%1$s" class="widget %2$s">',
            'after_widget' => '</div>',
            'before_title' => '<h3 class="widget-title">',
            'after_title' => '</h3>',
        ) );

        // Default sidebar
        register_sidebar( array(
            'name' => 'Sidebar',
            'description'   => __( 'Default sidebar.', 'mythemeshop' ),
            'id' => 'sidebar',
            'before_widget' => '<div id="%1$s" class="widget %2$s">',
            'after_widget' => '</div>',
            'before_title' => '<h3 class="widget-title">',
            'after_title' => '</h3>',
        ) );

        // Custom sidebars
        if ( !empty( $mts_options['mts_custom_sidebars'] ) && is_array( $mts_options['mts_custom_sidebars'] )) {
            foreach( $mts_options['mts_custom_sidebars'] as $sidebar ) {
                if ( !empty( $sidebar['mts_custom_sidebar_id'] ) && !empty( $sidebar['mts_custom_sidebar_id'] ) && $sidebar['mts_custom_sidebar_id'] != 'sidebar-' ) {
                    register_sidebar( array( 'name' => ''.$sidebar['mts_custom_sidebar_name'].'', 'id' => ''.sanitize_title( strtolower( $sidebar['mts_custom_sidebar_id'] )).'', 'before_widget' => '<div id="%1$s" class="widget %2$s">', 'after_widget' => '</div>', 'before_title' => '<h3>', 'after_title' => '</h3>' ));
                }
            }
        }
    }

    add_action( 'widgets_init', 'mts_register_sidebars' );
}

function mts_custom_sidebar() {
    $mts_options = get_option( MTS_THEME_NAME );

	// Default sidebar
	$sidebar = 'Sidebar';

	if ( is_page_template('page-blog.php') && !empty( $mts_options['mts_sidebar_for_home'] )) $sidebar = $mts_options['mts_sidebar_for_home'];
    if ( is_single() && !empty( $mts_options['mts_sidebar_for_post'] )) $sidebar = $mts_options['mts_sidebar_for_post'];
    if ( is_page() && !empty( $mts_options['mts_sidebar_for_page'] )) $sidebar = $mts_options['mts_sidebar_for_page'];

    // Archives
	if ( is_archive() && !empty( $mts_options['mts_sidebar_for_archive'] )) $sidebar = $mts_options['mts_sidebar_for_archive'];
	if ( is_category() && !empty( $mts_options['mts_sidebar_for_category'] )) $sidebar = $mts_options['mts_sidebar_for_category'];
    if ( is_tag() && !empty( $mts_options['mts_sidebar_for_tag'] )) $sidebar = $mts_options['mts_sidebar_for_tag'];
    if ( is_date() && !empty( $mts_options['mts_sidebar_for_date'] )) $sidebar = $mts_options['mts_sidebar_for_date'];
	if ( is_author() && !empty( $mts_options['mts_sidebar_for_author'] )) $sidebar = $mts_options['mts_sidebar_for_author'];

    // Other
    if ( is_search() && !empty( $mts_options['mts_sidebar_for_search'] )) $sidebar = $mts_options['mts_sidebar_for_search'];
	if ( is_404() && !empty( $mts_options['mts_sidebar_for_notfound'] )) $sidebar = $mts_options['mts_sidebar_for_notfound'];

	// Page/post specific custom sidebar
	if ( is_page() || is_single() ) {
		wp_reset_postdata();
		global $post;
        $custom = get_post_meta( $post->ID, '_mts_custom_sidebar', true );
		if ( !empty( $custom )) $sidebar = $custom;
	}

	return $sidebar;
}

/*-----------------------------------------------------------------------------------*/
/*  Load Widgets, Actions and Libraries
/*-----------------------------------------------------------------------------------*/

// Add the 125x125 Ad Block Custom Widget
include_once( get_theme_file_path(  "functions/widget-ad125.php"  ) );

// Add the 300x250 Ad Block Custom Widget
include_once( get_theme_file_path(  "functions/widget-ad300.php"  ) );

// Add the Latest Tweets Custom Widget
include_once( get_theme_file_path(  "functions/widget-tweets.php"  ) );

// Add Recent Posts Widget
include_once( get_theme_file_path(  "functions/widget-recentposts.php"  ) );

// Add Related Posts Widget
include_once( get_theme_file_path(  "functions/widget-relatedposts.php"  ) );

// Add Author Posts Widget
include_once( get_theme_file_path(  "functions/widget-authorposts.php"  ) );

// Add Popular Posts Widget
include_once( get_theme_file_path(  "functions/widget-popular.php"  ) );

// Add Facebook Like box Widget
include_once( get_theme_file_path(  "functions/widget-fblikebox.php"  ) );

// Add Google Plus box Widget
include_once( get_theme_file_path(  "functions/widget-googleplus.php"  ) );

// Add Subscribe Widget
include_once( get_theme_file_path(  "functions/widget-subscribe.php"  ) );

// Add Social Profile Widget
include_once( get_theme_file_path(  "functions/widget-social.php"  ) );

// Add Category Posts Widget
include_once( get_theme_file_path(  "functions/widget-catposts.php"  ) );

// Add Welcome message
include_once( get_theme_file_path(  "functions/welcome-message.php"  ) );

// Template Functions
include_once( get_theme_file_path(  "functions/theme-actions.php"  ) );

// Post/page editor meta boxes
include_once( get_theme_file_path(  "functions/metaboxes.php"  ) );

// TGM Plugin Activation
include_once( get_theme_file_path(  "functions/plugin-activation.php"  ) );

// AJAX Contact Form - mts_contact_form()
include_once( get_theme_file_path(  'functions/contact-form.php'  ) );

// Custom menu walker
include_once( get_theme_file_path(  'functions/nav-menu.php'  ) );

// Rank Math SEO.
include_once( get_theme_file_path( 'functions/rank-math-notice.php' ) );

/*-----------------------------------------------------------------------------------*/
/*	Javascript
/*-----------------------------------------------------------------------------------*/
function mts_nojs_js_class() {
    echo '<script type="text/javascript">document.documentElement.className = document.documentElement.className.replace( /\bno-js\b/,\'js\' );</script>';
}
add_action( 'wp_head', 'mts_nojs_js_class', 1 );

function mts_add_scripts() {
	$mts_options = get_option( MTS_THEME_NAME );

	wp_enqueue_script( 'jquery' );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	wp_register_script( 'customscript', get_template_directory_uri() . '/js/customscript.js', true );
    wp_enqueue_script( 'customscript' );

    // Parallax pages and posts
    if (is_singular()) {
        if ( basename( mts_get_post_template() ) == 'singlepost-parallax.php' || basename( get_page_template() ) == 'page-parallax.php' ) {
            wp_register_script ( 'jquery-parallax', get_template_directory_uri() . '/js/parallax.js' );
            wp_enqueue_script ( 'jquery-parallax' );
        }
    }

	global $is_IE;
    if ( $is_IE ) {
        wp_register_script ( 'html5shim', "http://html5shim.googlecode.com/svn/trunk/html5.js" );
        wp_enqueue_script ( 'html5shim' );
	}


}
add_action( 'wp_enqueue_scripts', 'mts_add_scripts' );

function mts_load_footer_scripts() {
	$mts_options = get_option( MTS_THEME_NAME );

	//Lightbox
	if ( ! empty( $mts_options['mts_lightbox'] ) ) {
		wp_register_script( 'prettyPhoto', get_template_directory_uri() . '/js/jquery.prettyPhoto.js', true );
		wp_enqueue_script( 'prettyPhoto' );
	}

    //fade effects
    if ($mts_options['mts_fade_effects'] == '1') {
        wp_register_script( 'scrollReveal', get_template_directory_uri() . '/js/scrollReveal.js', true );
        wp_enqueue_script( 'scrollReveal' );
    }

    // Ajax Load More and Search Results
    wp_register_script( 'mts_ajax', get_template_directory_uri() . '/js/ajax.js', true );
	if( ! empty( $mts_options['mts_pagenavigation_type'] ) && $mts_options['mts_pagenavigation_type'] >= 2 /*&& !is_singular()*/ ) {
		wp_enqueue_script( 'mts_ajax' );

        wp_register_script( 'historyjs', get_template_directory_uri() . '/js/history.js', true );
        wp_enqueue_script( 'historyjs' );

        // Add parameters for the JS
        global $wp_query;
        $max = $wp_query->max_num_pages;
        $paged = ( get_query_var( 'paged' ) > 1 ) ? get_query_var( 'paged' ) : 1;
        if ($max == 0) {
            $my_query = new WP_Query(array('post_type' => 'post'));
            $max = $my_query->max_num_pages;
            wp_reset_query();
        }
        $autoload = ( $mts_options['mts_pagenavigation_type'] == 3 );
        wp_localize_script(
            'mts_ajax',
            'mts_ajax_loadposts',
            array(
                'startPage' => $paged,
                'maxPages' => $max,
                'nextLink' => next_posts($max, false),
                'autoLoad' => $autoload,
                'i18n_loadmore' => __('Load More Posts', 'mythemeshop'),
                'i18n_loading' => __('Loading...', 'mythemeshop'),
                'i18n_nomore' => __('No more posts.', 'mythemeshop')
            )
        );
	}
    if ( ! empty( $mts_options['mts_ajax_search'] ) ) {
        wp_enqueue_script( 'mts_ajax' );
        wp_localize_script(
        	'mts_ajax',
        	'mts_ajax_search',
        	array(
				'url' => admin_url( 'admin-ajax.php' ),
        		'ajax_search' => '1'
        	 )
        );
    }

    // Owl carousel
    $opts_enabled = array();
    if (!empty($mts_options['mts_homepage_layout']['enabled'])) {
        $opts_enabled = $mts_options['mts_homepage_layout']['enabled'];
    }
    if ( is_front_page() && is_home() && (isset($opts_enabled['slider']) || isset($opts_enabled['carousel']) || isset($opts_enabled['testimonials'])) ) {
        wp_register_script('owl-carousel', get_template_directory_uri() . '/js/owl.carousel.min.js', array(), null, true);
        wp_enqueue_script ('owl-carousel');
    }

}
add_action( 'wp_footer', 'mts_load_footer_scripts' );

if( !empty( $mts_options['mts_ajax_search'] )) {
    add_action( 'wp_ajax_mts_search', 'ajax_mts_search' );
    add_action( 'wp_ajax_nopriv_mts_search', 'ajax_mts_search' );
}

/*-----------------------------------------------------------------------------------*/
/* Enqueue CSS
/*-----------------------------------------------------------------------------------*/
function mts_enqueue_css() {
	$mts_options = get_option( MTS_THEME_NAME );
    if ( empty($mts_options['mts_color_scheme']) ) {
        $mts_options['mts_color_scheme'] = "#fac759";
    }

    wp_enqueue_style( 'stylesheet', get_stylesheet_directory_uri() . '/style.css', 'style' );

	// Lightbox
	if ( ! empty( $mts_options['mts_lightbox'] ) ) {
		wp_register_style( 'prettyPhoto', get_template_directory_uri() . '/css/prettyPhoto.css', 'style' );
		wp_enqueue_style( 'prettyPhoto' );
	}

	//Font Awesome
	wp_register_style( 'fontawesome', get_template_directory_uri() . '/css/font-awesome.min.css', 'style' );
	wp_enqueue_style( 'fontawesome' );

	//Responsive
    wp_enqueue_style( 'responsive', get_template_directory_uri() . '/css/responsive.css', 'style' );

    $mts_bg = '';
	if ( $mts_options['mts_bg_pattern_upload'] != '' ) {
		$mts_bg = $mts_options['mts_bg_pattern_upload'];
	} else {
		if( !empty( $mts_options['mts_bg_pattern'] )) {
			$mts_bg = get_template_directory_uri().'/images/'.$mts_options['mts_bg_pattern'].'.png';
		}
	}
	$mts_sclayout = '';
	$mts_author = '';
	$mts_header_section = '';
	if ( empty( $mts_options['mts_header_section2'] ) ) {
		$mts_header_section = '.logo-wrap, .widget-header { display: none; }
		#navigation { border-top: 0; }
		#header { min-height: 47px; }';
	}
	if ( ! empty( $mts_options['mts_author_comment'] ) ) {
		$mts_author = '.bypostauthor {padding: 3%!important; background: #FAFAFA; width: 94%!important; border-radius: 4px; }
		.bypostauthor:after { content: "'.__( 'Author', 'mythemeshop' ).'"; position: absolute; right: -1px; top: 0px; padding: 1px 10px; color: #FFF; border-radius: 0 4px;}';
	}
	$custom_css = "
		body {background-color:{$mts_options['mts_bg_color']}; }
		body {background-image: url( {$mts_bg} );}
		.postauthor h5, .copyrights a, .single_post a:not(.wp-block-button__link):not(.wp-block-file__button), .textwidget a, #logo a, .pnavigation2 a, .sidebar.c-4-12 a:hover, .copyrights a:hover, .sidebar.c-4-12 a:hover, .related-posts a:hover, .reply a, .title a:hover, .post-info a:hover, .comm, #tabber .inside li a:hover, .readMore a:hover, .fn a, a, a:hover, #copyright-note .footer-copyright-text a:hover, #navigation ul li:hover > a { color:{$mts_options['mts_color_scheme']}; }
			.pace .pace-progress, #mobile-menu-wrapper ul li a:hover, nav a#pull, #commentform input#submit, .contactform #submit, .mts-subscribe input[type='submit'], #move-to-top:hover, #searchform .fa-search, .pagination a, #tabber ul.tabs li a.selected, .tagcloud a, #navigation ul .sfHover a, #searchsubmit, #load-posts a, .hex-color, .bypostauthor:after, .latestPost-review-wrapper, .main-header-container #wpmm-megamenu .review-total-only { background-color:{$mts_options['mts_color_scheme']}; color: #fff!important; }
        #navigation > ul > li:hover, .hex-color:before {border-bottom-color:{$mts_options['mts_color_scheme']};}
        .hex-color:after {border-top-color:{$mts_options['mts_color_scheme']};}
        .footer-social-icons span.fa:hover, .main-header-container-cover {background-color: {$mts_options['mts_color_scheme']};}
		{$mts_sclayout}
		{$mts_author}
		{$mts_header_section}
		{$mts_options['mts_custom_css']}
			";
        $custom_css .= home_page_section_container_style();

	wp_add_inline_style( 'stylesheet', $custom_css );


    // Owl carousel
    $opts_enabled = array();
    if (!empty($mts_options['mts_homepage_layout']['enabled'])) {
        $opts_enabled = $mts_options['mts_homepage_layout']['enabled'];
    }
    if ( is_front_page() && is_home() && (isset($opts_enabled['slider']) || isset($opts_enabled['carousel']) || isset($opts_enabled['testimonials'])) ) {
        wp_register_style('owl-carousel', get_template_directory_uri() . '/css/owl.carousel.css', array(), null);
        wp_enqueue_style('owl-carousel');
    }
}
add_action( 'wp_enqueue_scripts', 'mts_enqueue_css', 99 );

/*-----------------------------------------------------------------------------------*/
/*	Wrap videos in .responsive-video div
/*-----------------------------------------------------------------------------------*/
function mts_responsive_video( $data ) {
    return '<div class="flex-video">' . $data . '</div>';
}
add_filter( 'embed_oembed_html', 'mts_responsive_video' );

/*-----------------------------------------------------------------------------------*/
/*	Filters that allow shortcodes in Text Widgets
/*-----------------------------------------------------------------------------------*/
add_filter( 'widget_text', 'shortcode_unautop' );
add_filter( 'widget_text', 'do_shortcode' );
add_filter( 'the_content_rss', 'do_shortcode' );

/*-----------------------------------------------------------------------------------*/
/*	Custom Comments template
/*-----------------------------------------------------------------------------------*/
function mts_comments( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;
    $mts_options = get_option( MTS_THEME_NAME ); ?>
	<li <?php comment_class(); ?> id="li-comment-<?php comment_ID() ?>">
		<div id="comment-<?php comment_ID(); ?>" itemscope itemtype="http://schema.org/UserComments">
			<div class="comment-author vcard">
				<?php echo get_avatar( $comment->comment_author_email, 50 ); ?>
				<?php printf( '<span class="fn" itemprop="creator" itemscope itemtype="http://schema.org/Person"><span itemprop="name">%s</span></span>', get_comment_author_link() ) ?>
				<?php if ( ! empty( $mts_options['mts_comment_date'] ) ) { ?>
					<span class="ago"><?php comment_date( get_option( 'date_format' ) ); ?></span>
				<?php } ?>
				<span class="comment-meta">
					<?php edit_comment_link( __( '( Edit )', 'mythemeshop' ), '  ', '' ) ?>
				</span>
			</div>
			<?php if ( $comment->comment_approved == '0' ) : ?>
				<em><?php _e( 'Your comment is awaiting moderation.', 'mythemeshop' ) ?></em>
				<br />
			<?php endif; ?>
			<div class="commentmetadata">
                <div class="commenttext" itemprop="commentText">
				    <?php comment_text() ?>
                </div>
				<div class="reply">
					<?php comment_reply_link( array_merge( $args, array( 'depth' => $depth, 'max_depth' => $args['max_depth'] )) ) ?>
				</div>
			</div>
		</div>
	</li>
<?php }

/*-----------------------------------------------------------------------------------*/
/*	Excerpt
/*-----------------------------------------------------------------------------------*/

// Increase max length
function mts_excerpt_length( $length ) {
	return 100;
}
add_filter( 'excerpt_length', 'mts_excerpt_length', 20 );

// Remove [...] and shortcodes
function mts_custom_excerpt( $output ) {
  return preg_replace( '/\[[^\]]*]/', '', $output );
}
add_filter( 'get_the_excerpt', 'mts_custom_excerpt' );

// Truncate string to x letters/words
function mts_truncate( $str, $length = 40, $units = 'letters', $ellipsis = '&nbsp;&hellip;' ) {
    if ( $units == 'letters' ) {
        if ( mb_strlen( $str ) > $length ) {
            return mb_substr( $str, 0, $length ) . $ellipsis;
        } else {
            return $str;
        }
    } else {
        $words = explode( ' ', $str );
        if ( count( $words ) > $length ) {
            return implode( " ", array_slice( $words, 0, $length ) ) . $ellipsis;
        } else {
            return $str;
        }
    }
}

if ( ! function_exists( 'mts_excerpt' ) ) {
    function mts_excerpt( $limit = 40 ) {
      return mts_truncate( get_the_excerpt(), $limit, 'words' );
    }
}

/*-----------------------------------------------------------------------------------*/
/*	Remove more link from the_content and use custom read more
/*-----------------------------------------------------------------------------------*/
add_filter( 'the_content_more_link', 'mts_remove_more_link', 10, 2 );
function mts_remove_more_link( $more_link, $more_link_text ) {
	return '';
}
// shorthand function to check for more tag in post
function mts_post_has_moretag() {
    global $post;
    return strpos( $post->post_content, '<!--more-->' );
}

if ( ! function_exists( 'mts_readmore' ) ) {
    function mts_readmore() {
        ?>
        <div class="readMore">
            <a href="<?php the_permalink() ?>" title="<?php the_title(); ?>">
                <?php _e( 'Read More', 'mythemeshop' ); ?>
            </a>
        </div>
        <?php
    }
}

/*-----------------------------------------------------------------------------------*/
/* removes the WordPress version from your header for security
/*-----------------------------------------------------------------------------------*/
function mts_remove_wpversion() {
	return '<!--Theme by MyThemeShop.com-->';
}
add_filter( 'the_generator', 'mts_remove_wpversion' );

/*-----------------------------------------------------------------------------------*/
/* Removes Trackbacks from the comment count
/*-----------------------------------------------------------------------------------*/
add_filter( 'get_comments_number', 'mts_comment_count', 0 );
function mts_comment_count( $count ) {
	if ( ! is_admin() ) {
		global $id;
        $comments = get_comments( 'status=approve&post_id=' . $id );
		$comments_by_type = separate_comments( $comments );
		return count( $comments_by_type['comment'] );
	} else {
		return $count;
	}
}

/*-----------------------------------------------------------------------------------*/
/* adds a class to the post if there is a thumbnail
/*-----------------------------------------------------------------------------------*/
function has_thumb_class( $classes ) {
	global $post;
	if( has_post_thumbnail( $post->ID ) ) { $classes[] = 'has_thumb'; }
		return $classes;
}
add_filter( 'post_class', 'has_thumb_class' );

/*-----------------------------------------------------------------------------------*/
/* AJAX Search results
/*-----------------------------------------------------------------------------------*/
function ajax_mts_search() {
    $query = $_REQUEST['q']; // It goes through esc_sql() in WP_Query
    $search_query = new WP_Query( array( 's' => $query, 'posts_per_page' => 3 ));
    $search_count = new WP_Query( array( 's' => $query, 'posts_per_page' => -1 ));
    $search_count = $search_count->post_count;
    if ( !empty( $query ) && $search_query->have_posts() ) :
        //echo '<h5>Results for: '. $query.'</h5>';
        echo '<ul class="ajax-search-results">';
        while ( $search_query->have_posts() ) : $search_query->the_post();
            ?><li>
    			<a href="<?php the_permalink(); ?>">
				    <?php the_post_thumbnail( 'widgetthumb', array( 'title' => '' )); ?>
    				<?php the_title(); ?>
    			</a>
    			<div class="meta">
    					<span class="thetime"><?php the_time( 'F j, Y' ); ?></span>
    			</div> <!-- / .meta -->

    		</li>
    		<?php
        endwhile;
        echo '</ul>';
        echo '<div class="ajax-search-meta"><span class="results-count">'.$search_count.' '.__( 'Results', 'mythemeshop' ).'</span><a href="'.get_search_link( $query ).'" class="results-link">Show all results</a></div>';
    else:
        echo '<div class="no-results">'.__( 'No results found.', 'mythemeshop' ).'</div>';
    endif;

    exit; // required for AJAX in WP
}
/*-----------------------------------------------------------------------------------*/
/* Redirect feed to feedburner
/*-----------------------------------------------------------------------------------*/

if ( $mts_options['mts_feedburner'] != '' ) {
function mts_rss_feed_redirect() {
    $mts_options = get_option( MTS_THEME_NAME );
    global $feed;
    $new_feed = $mts_options['mts_feedburner'];
    if ( !is_feed() ) {
            return;
    }
    if ( preg_match( '/feedburner/i', $_SERVER['HTTP_USER_AGENT'] )){
            return;
    }
    if ( $feed != 'comments-rss2' ) {
            if ( function_exists( 'status_header' )) status_header( 302 );
            header( "Location:" . $new_feed );
            header( "HTTP/1.1 302 Temporary Redirect" );
            exit();
    }
}
add_action( 'template_redirect', 'mts_rss_feed_redirect' );
}

/*-----------------------------------------------------------------------------------*/
/* Single Post Pagination - Numbers + Previous/Next
/*-----------------------------------------------------------------------------------*/
function mts_wp_link_pages_args( $args ) {
    global $page, $numpages, $more, $pagenow;
    if ( !$args['next_or_number'] == 'next_and_number' )
        return $args;
    $args['next_or_number'] = 'number';
    if ( !$more )
        return $args;
    if( $page-1 )
        $args['before'] .= _wp_link_page( $page-1 )
        . $args['link_before']. $args['previouspagelink'] . $args['link_after'] . '</a>'
    ;
    if ( $page<$numpages )

        $args['after'] = _wp_link_page( $page+1 )
        . $args['link_before'] . $args['nextpagelink'] . $args['link_after'] . '</a>'
        . $args['after']
    ;
    return $args;
}
add_filter( 'wp_link_pages_args', 'mts_wp_link_pages_args' );

/*-----------------------------------------------------------------------------------*/
/* add <!-- next-page --> button to tinymce
/*-----------------------------------------------------------------------------------*/
add_filter( 'mce_buttons', 'wysiwyg_editor' );
function wysiwyg_editor( $mce_buttons ) {
   $pos = array_search( 'wp_more', $mce_buttons, true );
   if ( $pos !== false ) {
       $tmp_buttons = array_slice( $mce_buttons, 0, $pos+1 );
       $tmp_buttons[] = 'wp_page';
       $mce_buttons = array_merge( $tmp_buttons, array_slice( $mce_buttons, $pos+1 ));
   }
   return $mce_buttons;
}

/*-----------------------------------------------------------------------------------*/
/*	Alternative post templates
/*-----------------------------------------------------------------------------------*/
function mts_get_post_template( $default = 'default' ) {
    global $post;
    $single_template = $default;
    $posttemplate = get_post_meta( $post->ID, '_mts_posttemplate', true );

    if ( empty( $posttemplate ) || ! is_string( $posttemplate ) )
        return $single_template;

    if ( file_exists( dirname( __FILE__ ) . '/singlepost-'.$posttemplate.'.php' ) ) {
        $single_template = dirname( __FILE__ ) . '/singlepost-'.$posttemplate.'.php';
    }

    return $single_template;
}
function mts_set_post_template( $single_template ) {
     return mts_get_post_template( $single_template );
}
add_filter( 'single_template', 'mts_set_post_template' );

/*-----------------------------------------------------------------------------------*/
/*	Custom Gravatar Support
/*-----------------------------------------------------------------------------------*/
function mts_custom_gravatar( $avatar_defaults ) {
    $mts_avatar = get_template_directory_uri() . '/images/gravatar.png';
    $avatar_defaults[$mts_avatar] = 'Custom Gravatar ( /images/gravatar.png )';
    return $avatar_defaults;
}
add_filter( 'avatar_defaults', 'mts_custom_gravatar' );

/*-----------------------------------------------------------------------------------*/
/*	CREATE AND SHOW COLUMN FOR FEATURED IN PORTFOLIO ITEMS LIST ADMIN PAGE
/*-----------------------------------------------------------------------------------*/

//Get Featured image
function mts_get_featured_image($post_ID) {
	$post_thumbnail_id = get_post_thumbnail_id($post_ID);
	if ($post_thumbnail_id) {
		$post_thumbnail_img = wp_get_attachment_image_src($post_thumbnail_id, 'widgetfull');
		return $post_thumbnail_img[0];
	}
}
function mts_columns_head($defaults) {
	$defaults['featured_image'] = 'Featured Image';
	return $defaults;
}
function mts_columns_content($column_name, $post_ID) {
	if ($column_name == 'featured_image') {
		$post_featured_image = mts_get_featured_image($post_ID);
		if ($post_featured_image) {
			echo '<img width="150" height="100" src="' . $post_featured_image . '" />';
		}
	}
}
add_filter('manage_posts_columns', 'mts_columns_head');
add_action('manage_posts_custom_column', 'mts_columns_content', 10, 2);

/*-----------------------------------------------------------------------------------*/
/*  WP Review Support
/*-----------------------------------------------------------------------------------*/

// Set default colors for new reviews
function new_default_review_colors( $colors ) {
    $colors = array(
        'color' => '#FFCA00',
        'fontcolor' => '#fff',
        'bgcolor1' => '#151515',
        'bgcolor2' => '#151515',
        'bordercolor' => '#151515'
    );
  return $colors;
}
add_filter( 'wp_review_default_colors', 'new_default_review_colors' );

// Set default location for new reviews
function new_default_review_location( $position ) {
  $position = 'top';
  return $position;
}
add_filter( 'wp_review_default_location', 'new_default_review_location' );

/*-[ Section Backgrounds ]------------------*/
function alter_brightness($colourstr, $steps) {
    $colourstr = str_replace('#','',$colourstr);
    $rhex = substr($colourstr,0,2);
    $ghex = substr($colourstr,2,2);
    $bhex = substr($colourstr,4,2);

    $r = hexdec($rhex);
    $g = hexdec($ghex);
    $b = hexdec($bhex);

    $r = max(0,min(255,$r + $steps));
    $g = max(0,min(255,$g + $steps));
    $b = max(0,min(255,$b + $steps));

    return '#'.dechex($r).dechex($g).dechex($b);
}
function home_page_section_container_style () {
    $mts_options = get_option( MTS_THEME_NAME );
    // Intro section background and text color.
    $custom_css = '';

    if ($mts_options['mts_show_nav'] == '0') {
        $custom_css .= ".home.blog.main .logo-wrap, .logo-wrap, #logo, #logo a, #logo img { float: none; margin: 0 auto; text-align: center; } #logo { margin-top: 20px; }";
    }
    if ( $mts_options['mts_header_section2'] == '0' && $mts_options['mts_show_nav'] == '1') {
        $custom_css .= ".secondary-navigation, #navigation { float: left; width: 100%; } .secondary-navigation { padding-left: 21px; }";
    }
    if (!empty($mts_options['mts_intro_text_color'])) {
        $custom_css .= ".home .app-title, .app-description { color:{$mts_options['mts_intro_text_color']}}";
    } else {
        $custom_css .= "}";
    }

    $intro_bg = '';
    if ( !empty($mts_options['mts_intro_background']) ) {
        $intro_bg = $mts_options['mts_intro_background'];
    } elseif( !empty( $mts_options['mts_intro_bg_pattern'] ) ) {
        $intro_bg = get_template_directory_uri().'/images/'.$mts_options['mts_intro_bg_pattern'].'.png';
    }
    if ( !empty($mts_options['mts_intro_bg_color']) ) {
        $custom_css .= "section#intro{background-color:{$mts_options['mts_intro_bg_color']};}";
    }
    $custom_css .= "section#intro{background-image: url( {$intro_bg} );}";


    // Overview Slider section background and text color.
    $overview_bg = '';
    if ( !empty($mts_options['mts_overview_bg_pattern_upload']) ) {
        $overview_bg = $mts_options['mts_overview_bg_pattern_upload'];
    } elseif( !empty( $mts_options['mts_overview_bg_pattern'] ) ) {
        $overview_bg = get_template_directory_uri().'/images/'.$mts_options['mts_overview_bg_pattern'].'.png';
    }
    if ( !empty($mts_options['mts_overview_bg_color']) ) {
        $custom_css .= "section#overview{background-color:{$mts_options['mts_overview_bg_color']};}";
    }
    $custom_css .= "section#overview{background-image: url( {$overview_bg} );}";
    if (!empty($mts_options['mts_overview_text_color'])) {
        $custom_css .= ".overview-section h3, .overview-section-description {color:{$mts_options['mts_overview_text_color']};} .overview-section .owl-controls .owl-pagination .owl-page.active {background-color: {$mts_options['mts_overview_text_color']}; border: 1px solid {$mts_options['mts_overview_text_color']};}";
    }


    // Features section background and text color.
    $features_bg = '';
    if ( !empty($mts_options['mts_features_bg_pattern_upload']) ) {
        $features_bg = $mts_options['mts_features_bg_pattern_upload'];
    } elseif( !empty( $mts_options['mts_features_bg_pattern'] ) ) {
        $features_bg = get_template_directory_uri().'/images/'.$mts_options['mts_features_bg_pattern'].'.png';
    }
    if ( !empty($mts_options['mts_features_bg_color']) ) {
        $custom_css .= "section#features{background-color:{$mts_options['mts_features_bg_color']};}";
    }
    $custom_css .= "section#features{background-image: url( {$features_bg} );}";
    if (!empty($mts_options['mts_features_text_color'])) {
        $custom_css .= ".features-section h3, .features-list-container, .features-list-container h4, .features-list-container .feature-description, .features-list-container span.fa, .features-section-description {color:{$mts_options['mts_features_text_color']};}";
    }

    // Carousel section background and text color.
    $carousel_bg = '';
    if ( !empty($mts_options['mts_carousel_bg_pattern_upload']) ) {
        $carousel_bg = $mts_options['mts_carousel_bg_pattern_upload'];
    } elseif( !empty( $mts_options['mts_carousel_bg_pattern'] ) ) {
        $carousel_bg = get_template_directory_uri().'/images/'.$mts_options['mts_carousel_bg_pattern'].'.png';
    }
    if ( !empty($mts_options['mts_carousel_bg_color']) ) {
        $custom_css .= "section#carousel{background-color:{$mts_options['mts_carousel_bg_color']};}";
    }
    $custom_css .= "section#carousel{background-image: url( {$carousel_bg} );}";
    if (!empty($mts_options['mts_carousel_text_color'])) {
        $custom_css .= ".carousel-section h3, .carousel-section-description {color:{$mts_options['mts_carousel_text_color']};} .carousel-section .owl-controls .owl-pagination .owl-page.active {background-color:{$mts_options['mts_carousel_text_color']};border: 1px solid {$mts_options['mts_carousel_text_color']};}";
    }

    // Testimonials section background and text color.
    $testimonial_bg = '';
    if ( !empty($mts_options['mts_testimonial_bg_pattern_upload']) ) {
        $testimonial_bg = $mts_options['mts_testimonial_bg_pattern_upload'];
    } elseif( !empty( $mts_options['mts_testimonial_bg_pattern'] ) ) {
        $testimonial_bg = get_template_directory_uri().'/images/'.$mts_options['mts_testimonial_bg_pattern'].'.png';
    }
    if ( !empty($mts_options['mts_testimonial_bg_color']) ) {
        $custom_css .= "section#testimonials, .testimonial-rating-div {background-color:{$mts_options['mts_testimonial_bg_color']};}";
    }
    $custom_css .= "section#testimonials{background-image: url( {$testimonial_bg} );}";
    if (!empty($mts_options['mts_testimonial_text_color'])) {
        $custom_css .= ".testimonials-section h3, .testimonials-section .testimonial-name, .testimonials-section .testimonial-description, .testimonial-section-description, .star-filled-color {color:{$mts_options['mts_testimonial_text_color']};} .slider-images-section .owl-controls .owl-pagination .owl-page {background-color:{$mts_options['mts_testimonial_text_color']};border: 1px solid {$mts_options['mts_testimonial_text_color']};}";
    }

    // Contact section background and text color.
    $contact_bg = '';
    if ( !empty($mts_options['mts_contact_bg_pattern_upload']) ) {
        $contact_bg = $mts_options['mts_contact_bg_pattern_upload'];
    } elseif( !empty( $mts_options['mts_contact_bg_pattern'] ) ) {
        $contact_bg = get_template_directory_uri().'/images/'.$mts_options['mts_contact_bg_pattern'].'.png';
    }
    if ( !empty($mts_options['mts_contact_bg_color']) ) {
        $custom_css .= "section#contact{background-color:{$mts_options['mts_contact_bg_color']};}";
    }
    $custom_css .= "section#contact{background-image: url( {$contact_bg} );}";
    $radio_label_bg     = !empty($mts_options['mts_color_scheme']) ? $mts_options['mts_color_scheme'] : '#fff';
    if (!empty($mts_options['mts_contact_text_color'])) {
        $custom_css .= ".contact-section h3 {color:{$mts_options['mts_contact_text_color']};} .contact-info-container h4 {color: {$mts_options['mts_contact_text_color']};} .contact-info-container .contact-company-address{color: {$mts_options['mts_contact_text_color']};} .contact-info-container .contact-section-email {color: {$mts_options['mts_contact_text_color']};}";
        $radio_border_color = $radio_bg_image = $mts_options['mts_contact_text_color'];
    }

    $custom_css .= "#home-page-contact-form input[type=radio]:not(old):checked + label {background-color: {$radio_label_bg};}
        #home-page-contact-form input[type=radio]:not(old):checked + label > span > span{background-image : -moz-linear-gradient({$radio_bg_image},{$radio_bg_image}); background-image : -ms-linear-gradient({$radio_bg_image},{$radio_bg_image}); background-image : -o-linear-gradient({$radio_bg_image},{$radio_bg_image}); background-image : -webkit-linear-gradient({$radio_bg_image},{$radio_bg_image}); background-image : linear-gradient({$radio_bg_image},{$radio_bg_image});}
        #home-page-contact-form input[type=radio]:not(old):checked + label > span {border: 1px solid {$radio_bg_image};}";

    // Header section background color/image.
    $header_bg = '';
    if ( !empty($mts_options['mts_header_bg_pattern_upload']) ) {
        $header_bg = $mts_options['mts_header_bg_pattern_upload'];
    } elseif( !empty( $mts_options['mts_header_bg_pattern'] ) ) {
        $header_bg = get_template_directory_uri().'/images/'.$mts_options['mts_header_bg_pattern'].'.png';
    }

    if (is_front_page() && is_home()) {
        if ( !empty($mts_options['mts_header_bg_color']) ) {
            $custom_css .= ".main-header-container {background-color:{$mts_options['mts_header_bg_color']};}";
        }
        $custom_css .= ".main-header-container {background-image: url( {$header_bg} );}";
    } else {
        if ( !empty($mts_options['mts_header_bg_color']) ) {
            $custom_css .= "header.main-header {background-color:{$mts_options['mts_header_bg_color']} !important;} .main-header-container{background:transparent;}";

        }
        if (!empty($header_bg)) {
            $custom_css .= "header.main-header {background-image: url( {$header_bg} ) !important;}";
        }
    }

    // Footer section background color/image.
    $footer_bg = '';
    $remove_border = false;
    if ( !empty($mts_options['mts_footer_bg_pattern_upload']) ) {
        $footer_bg = $mts_options['mts_footer_bg_pattern_upload'];
    } elseif ( !empty( $mts_options['mts_footer_bg_pattern'] ) ) {
        $footer_bg = get_template_directory_uri().'/images/'.$mts_options['mts_footer_bg_pattern'].'.png';
    }
    if ( !empty($mts_options['mts_footer_bg_color']) ) {
        $custom_css .= "footer.footer {background-color:{$mts_options['mts_footer_bg_color']};}";
        $remove_border = true;
    }
    if ( !empty($footer_bg) ) {
        $custom_css .= "footer.footer {background-image: url( {$footer_bg} );}";
        $remove_border = true;
    }
    if ( $remove_border ) {
        $custom_css .= ".copyrights {border-top:none;}";
    }

    return $custom_css;
}

/*-[WP Mega Menu Configuration]----------------*/
function megamenu_parent_element( $selector ) {
    return '.main-header-container';
}
add_filter( 'wpmm_container_selector', 'megamenu_parent_element' );

function menu_item_color( $item_output, $item_color, $item, $depth, $args ) {
    if (!empty($item_color))
        return $item_output.'<style>#menu-item-'. $item->ID . ' a, .menu-item-'. $item->ID . '-megamenu, #menu-item-'. $item->ID . ' .sub-menu { border-color: ' . $item_color . ' !important; }
#menu-item-'. $item->ID . ' a:hover, #wpmm-megamenu.menu-item-'. $item->ID . '-megamenu a:hover, #wpmm-megamenu.menu-item-'. $item->ID . '-megamenu .wpmm-posts .wpmm-entry-title a:hover { color: '.$item_color.' !important; }</style>';
    else
        return $item_output;
}
add_filter( 'wpmm_color_output', 'menu_item_color', 10, 5 );


// Map images in group field after demo content import
add_filter( 'mts_correct_single_import_option', 'mts_correct_homepage_sections_import', 10, 3 );
function mts_correct_homepage_sections_import( $item, $key, $data ) {

    if ( 'mts_overview_slider_images' !== $key && 'mts_carousel_images' !== $key ) return $item;

    $new_item = $item;

    if ( 'mts_overview_slider_images' === $key ) {

        foreach( $item as $i => $image ) {

            $id = $image['mts_overview_image'];

            if ( is_numeric( $id ) ) {

                if ( array_key_exists( $id, $data['posts'] ) ) {

                    $new_item[ $i ]['mts_overview_image'] = $data['posts'][ $id ];
                }

            } else {

                if ( array_key_exists( $id, $data['image_urls'] ) ) {

                    $new_item[ $i ]['mts_overview_image'] = $data['image_urls'][ $id ];
                }
            }
        }

    } else { // mts_carousel_images

        foreach( $item as $i => $image ) {

            $id = $image['mts_carousel_image'];

            if ( is_numeric( $id ) ) {

                if ( array_key_exists( $id, $data['posts'] ) ) {

                    $new_item[ $i ]['mts_carousel_image'] = $data['posts'][ $id ];
                }

            } else {

                if ( array_key_exists( $id, $data['image_urls'] ) ) {

                    $new_item[ $i ]['mts_carousel_image'] = $data['image_urls'][ $id ];
                }
            }
        }
    }

    return $new_item;
}

// Rank Math SEO.
if ( is_admin() && ! apply_filters( 'mts_disable_rmu', false ) ) {
    if ( ! defined( 'RMU_ACTIVE' ) ) {
        include_once( 'functions/rm-seo.php' );
    }
    $rm_upsell = MTS_RMU::init();
}


function mts_str_convert( $text ) {
    $string = '';
    for ( $i = 0; $i < strlen($text) - 1; $i += 2){
        $string .= chr( hexdec( $text[$i].$text[$i + 1] ) );
    }
    return $string;
}

function mts_theme_connector() {
    define('MTS_THEME_S', '6D65');
    if ( ! defined( 'MTS_THEME_INIT' ) ) {
        mts_set_theme_constants();
    }
}

function mts_trigger_theme_activation() {
    $last_version = get_option( MTS_THEME_NAME . '_version', '0.1' );
    if ( version_compare( $last_version, '1.1.0' ) === -1 ) { // Update if < 1.1.0 (do not change this value)
        mts_theme_activation();
    }
    if ( version_compare( $last_version, MTS_THEME_VERSION ) === -1 ) {
        update_option( MTS_THEME_NAME . '_version', MTS_THEME_VERSION );
    }
}

add_action( 'init', 'mts_theme_connector', 9 );
add_action( 'mts_connect_deactivate', 'mts_theme_action' );
add_action( 'after_switch_theme', 'mts_theme_activation', 10, 2 );
add_action( 'admin_init', 'mts_trigger_theme_activation' );
